#
# spec file for package kdesvn
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kdesvn
Version:        2.1.0
Release:        bp156.7.8
Summary:        KDE Subversion Client
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://userbase.kde.org/Kdesvn
Source:         https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  kbookmarks-devel
BuildRequires:  kcodecs-devel
BuildRequires:  kcompletion-devel
BuildRequires:  kconfig-devel
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kdbusaddons-devel
BuildRequires:  kdoctools-devel
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  kitemviews-devel
BuildRequires:  kjobwidgets-devel
BuildRequires:  knotifications-devel
BuildRequires:  kparts-devel
BuildRequires:  kservice-devel
BuildRequires:  ktextwidgets-devel
BuildRequires:  kwallet-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  pkgconfig
BuildRequires:  subversion-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
# needed for the database
Requires:       libQt5Sql5-sqlite
Provides:       kde4-kdesvn = %{version}
Obsoletes:      kde4-kdesvn < %{version}
Obsoletes:      libsvnqt7 < %{version}

%description
kdesvn is a GUI client for subversion repositories.

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %suse_update_desktop_file -G "SVN Client" org.kde.kdesvn Development RevisionControl
  %find_lang %{name} --all-name --with-man
  %kf5_find_htmldocs
  %fdupes -s %{buildroot}%{_datadir}

%files -f %{name}.lang
%license COPYING COPYING.OpenSSL
%doc AUTHORS ChangeLog
%dir %{_kf5_iconsdir}/hicolor/96x96
%dir %{_kf5_iconsdir}/hicolor/96x96/actions
%dir %{_kf5_iconsdir}/hicolor/96x96/places
%doc %lang(en) %{_kf5_htmldir}/en/kdesvn/
%doc %lang(en) %{_kf5_mandir}/man1/kdesvn.1%{?ext_man}
%doc %lang(en) %{_kf5_mandir}/man1/kdesvnaskpass.1%{?ext_man}
%{_kf5_applicationsdir}/org.kde.kdesvn.desktop
%{_kf5_appstreamdir}/org.kde.kdesvn.appdata.xml
%{_kf5_bindir}/kdesvn
%{_kf5_bindir}/kdesvnaskpass
%{_kf5_configkcfgdir}/
%{_kf5_dbusinterfacesdir}/kf5_org.kde.kdesvnd.xml
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_kxmlguidir}/kdesvn/
%{_kf5_plugindir}/kdesvnpart.so
%{_kf5_plugindir}/kf5/kded/kdesvnd.so
%{_kf5_plugindir}/kio_ksvn.so
%{_kf5_servicesdir}/*.desktop
%{_kf5_servicesdir}/*.protocol
%{_kf5_servicesdir}/ServiceMenus/
%{_kf5_sharedir}/dbus-1/services/org.kde.kdesvnd.service
%{_kf5_sharedir}/kconf_update/
%{_kf5_sharedir}/kdesvn/

%changelog
* Wed Jul 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the libqt5-sqlite requirement.
* Fri Jul 12 2019 wbauer@tmo.at
- Update to 2.1.0
  * Compile with Qt5.13 (kde#409442)
  * Don't crash on exit when log fill thread is still running
    (kde#404734)
  * Enable 'Revert' action when a single directory with modified
    items is selected (kde#406425)
  * Don't accept richtext in commit message dialog (kde#401529)
  * Make buttons in sslprompt actually work (kde#327221)
  * Display relative path (including name of the checkout) in the
    titlebar (kde#391804)
  * Hide unchanged files resets folder and doesn’t hide all
    elements (kde#372423)
  * Add buttons "Add" and "Remove" to context menu when
    files are selected (kde#377041)
  * KDED5 crash after right-click in Dolphin (kde#383187)
  * Don't crash when the path contains a '@' (kde#375655)
  * Fix compilation with FreeBSD
  * Fix adding a new property to a svn entry
  * Removed support for subversion 1.6 and below
  * Code cleanups:
    + use c++11 functionality - nullptr, range-based for loops, ...
    + use new-style connects where possible
    + replace deprecated Qt functions
    + set Qt5.9 as minimum allowed Qt version
- Drop patches merged upstream:
  * fix-startup.patch
  * fix-crash.patch
  * fix-crash-root-path.patch
  * Fix-build-with-Qt-511.patch
- Add full Source URL
- Update build requirements
- Require libQt5Sql-sqlite, needed for the database
- Use %%kf5_find_htmldocs macro to get filelist of translated docs
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch to fix build with Qt 5.11.
* Sun Aug  6 2017 ch.ehrlicher@gmx.de
- Add fix-crash-root-path.patch to fix kded crash when the root
  path ('/') is checked for a working copy (kde#383187)
* Sat May 20 2017 wbauer@tmo.at
- Add fix-crash.patch to fix a crash when there's a '@' in the path
  (kde#375655)
* Tue Jan 24 2017 wbauer@tmo.at
- Add fix-startup.patch to fix starting kdesvn from the
  application menu (boo#1021486)
* Wed Dec  7 2016 wbauer@tmo.at
- update to 2.0.0
  * first release based on KDE Frameworks 5
  * no other relevant changes
- Drop Do-not-install-svnqt-static-lib.patch, it's included in this
  release
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Tue May 31 2016 wbauer@tmo.at
- update to 1.7.0
  * Bug 322021 - Action and notification strings are not really translatable
  * Bug 322182 - kdesvn mangles options passed to external conflict resolver
  * Bug 323403 - Add "Revert" option to context menu for files
  * Bug 323712 - Subversion 1.6.x support
  * Bug 324158 - kdesvn crash when a directory name contains the at (@) symbol
  * Bug 325074, 330624 - kdesvn crashed when getting logs.
  * Bug 332863 - Wish: Please add an "Unselect all"-buttton to commit dialoge
  * Bug 340772 - Committing two moves together leads to out-of-date errors
  * Bug 357297 - kdesvn crash after entering password
  * Bug 358032 - Crash after closing KDESVN
  * ubuntu bug: 619249 tcp ports specified in urls are being ignored when using svn:https
  * speedup db insertions into log-cache
  * various code cleanups (krazy, cppcheck, preparation for KF5)
  * libsvnqt is no longer a public api
  * remove last pieces from Qt3support
  * don't show disabled actions in contextmenu
  * highlight trailing spaces in diff output on modified lines
  * fix filtering in commit dialog
- Drop upstreamed patches:
  * fix_bug_address.patch
  * fix_crash_when_getting_logs.patch
  * let-kdelibs-create-uninstall-target.patch
  * KDE-BUG-357297-Run-ssh-add-every-time.patch
- Drop the libsvnqt7 and libsvnqt-devel subpackages, there is no
  shared libsvnqt andy more, and move its translations into the
  main package
- Add Do-not-install-svnqt-static-lib.patch from upstream, we don't
  want to install libsvnqt.a
- Adjust file lists
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Only recommend the kio_svn instead of require it. On Tumbleweed
  the kio_svn is not building due to upstream changes of SVN itself.
* Tue Dec 29 2015 opensuse.lietuviu.kalba@gmail.com
- Added KDE-BUG-357297-Run-ssh-add-every-time.patch, fix
  running ssh-add every time (kde#357297).
* Sat Oct 10 2015 hrvoje.senjan@gmail.com
- Added let-kdelibs-create-uninstall-target.patch, fix build when
  CMake's CMP002 policy is set to NEW (with kdelibs4 >= 4.14.11)
* Sat Jun 27 2015 wbauer@tmo.at
- Add fix_crash_when_getting_logs.patch: fixes a crash when getting
  logs with current subversion (boo#931401, kde#325074, kde#330624)
* Sun Jul  7 2013 cgiboudeaux@gmx.com
- Add fix_bug_address.patch. Redirects bug reports to bugs.kde.org
* Mon Apr 15 2013 tittiatcoke@gmail.com
- Explicit require for kio_svn and remove the
  /usr/share/kde4/services/svn*.protocol files from this package
  to avoid conflicts
* Fri Oct  5 2012 coolo@suse.com
- use a macro for library to avoid broken renames
* Tue Oct  2 2012 mailaender@opensuse.org
- update to 1.6.0
  * User may add (or remove) patterns to ignore recursive
  * greek translation
  * modified for working with subversion 1.7 interface
  * removed support for subversion less than version 1.5
  * revert commit in  working copy from within logwindow
  * fixed some problems with non canonical pathes and Urls which comes with subversion 1.7
  * re-added russian translation
- Remove the following patches, all upstream now:
  * kdesvn.diff
  * remove-nl.diff
  * kdesvn-virtual-inheritance.patch
  * kdesvn-gcc47.patch
* Sat Mar 24 2012 dimstar@opensuse.org
- Add kdesvn-gcc47.patch: Fix build with gcc 4.7.
* Wed Nov 30 2011 idoenmez@suse.de
- Fix build with Qt 4.8
* Tue Aug 30 2011 mlin@suse.com
- few fixes for RPMLINT warnings
  * add %%fdupes for files duplicated
  * do not obsoletes itself
- remove redundant BuildRequires
- clean up the specfile formatting
* Fri Jan 14 2011 wstephenson@novell.com
- update to 1.5.5
  * fixed problems while updating view after a subversion update of working copy
  * KNotify progress messages of KIO operation may switched off
* Sat Aug 21 2010 tittiatcoke@gmail.com
- update to 1.5.4
  * fixed problem ssh-askpass environment
* Fri Apr  9 2010 tittiatcoke@gmail.com
- update to 1.5.3
  * fixed a problem with some svn servers where version of server
    and svn-filesystem differs (ticket #765)
  * fixed wrong default depth for update in svnqt and frontend
* Thu Feb 11 2010 tittiatcoke@gmail.com
- update to 1.5.2
  * Fixed an unicode translation error when open folders
  * german translation updated
  * minor ui tweaks fixed
  * fix build and install on cygwin/win32 (patch taken from ticket #761, tnx)
* Sun Jan 17 2010 tittiatcoke@gmail.com
- update to 1.5.1
  * included an older fix from 1.4.x branch
  * additional bugfixes
* Mon Jan 11 2010 tittiatcoke@gmail.com
- update to 1.5.0
  * fixed performance problems on remote repositories, all special
    infos are now retrieved in background
  * integrated missing merge parameters for subversion 1.5 or newer
  * KIO operations send notify messages to KDE notify system
  * user may setup a timed check for updates in repository and/or
    local modified items
  * some UI fixes
* Sat Jan  2 2010 dmueller@suse.de
- tighten libsvnqt6 dependencies
* Sun Oct  4 2009 beineri@opensuse.org
- update to 1.4.1:
  * kdesvnaskpass checks if last given password were wrong and
    ignores stored pw in that case
  * fixed a buildproblem with qt < 4.5
  * fixed a crasher while update to new added items
* Sat Aug  1 2009 tittiatcoke@gmail.com
- update to 1.4.0
  * integrated subversion 1.6 api
  * some speedups in subversion interface
  * drag&drop re-worked, now it works as expected
  * KIO interface can now import files via drag&drop.
    With option set it is able edit/overwrite files, too.
  * integrated first repository specific settings
  * Revisiontree may ignore path prefixes (done with repository settings)
  * logcache overview, user may delete entries for repositories,
    see, how many entries and how large them are.
  * various small bugfixes and enhancements
* Sat Jul 11 2009 tittiatcoke@gmail.com
- update to 1.3.2
  * fixing crash when calling contextmenu in left panel. (#644,#643,#642,#639 and others)
  * fixed fontproblem in revision tree
  * fixed sorting error (#625)
* Sat Jun  6 2009 dmueller@suse.de
- update to 1.3.1 (bnc#510219):
  * fixed ui errors
  * fixed initial sort problem
  * inserted missing config option for not using the new left navigation tree
* Tue Apr 21 2009 dmueller@suse.de
- add missing runtime requires
* Mon Apr 20 2009 dmueller@suse.de
- add provides/obsoletes
* Mon Apr 20 2009 dmueller@suse.de
- update to 1.3.0:
  * kde4 port
  * new frontend which integrates a navigation panel
* Sat Apr  4 2009 coolo@suse.de
- refresh all patches to fix build
* Fri Oct 10 2008 wstephenson@suse.de
- update to 1.0.4:
  * due a backporting mistake from kde4 branch kdesvn 1.0.3 was not
    able to run - fixed
- update to 1.0.3
  * fixed a problem with paths containing multiple special chars
    like space
* Sat Sep 20 2008 stbinner@suse.de
- update to 1.0.2:
  * fixed distorted logic in "merge" parameter, results in working
    merge tracking with svn1.5, too.
* Mon Sep  8 2008 dmueller@suse.de
- update to 1.0.1:
  * fixed a crasher with svn 1.5
  * some smaller fixes
  * various bugfixes in buildsystem, build failure with svn 1.3
  * improvement in handling of logcache errors
* Mon Aug 18 2008 stbinner@suse.de
- update to 1.0.0:
  * implemented a sqlite-based logcache used by revision tree
  * dutch handbook added
  * kdesvn may work (simplified) offline
  * Passwords may hold in a memory cache until application ends
* Wed Jul 16 2008 stbinner@suse.de
- update to 0.14.6: fixes problems with accessing KWallet
* Wed May 28 2008 olh@suse.de
- update for subversion 1.5 API
* Fri May 23 2008 stbinner@suse.de
- update to fix utf8 errors with many repositories (bnc#393484)
* Mon May 19 2008 schwab@suse.de
- Fix configuration.
* Sun Apr 13 2008 dmueller@suse.de
- fix build against cmake 2.6
* Thu Apr  3 2008 dmueller@suse.de
- update to 0.14.3:
  * fixed problems with diff between moved elements
  * suppress useless messages
  * fix crash in logviewer
* Wed Feb 20 2008 stbinner@suse.de
- update to 0.14.2:
  * fixed various segfaults
  * updated/fixed translations
  * integrated a direct call to an externam conflict resolver tool
* Wed Nov 21 2007 stbinner@suse.de
- update to 0.14.1:
  * fixed a crasher when deleting items
  * updated frensh and lithuanian translation
* Mon Nov  5 2007 dmueller@suse.de
- split off development files / library package
* Mon Oct 29 2007 dmueller@suse.de
- fix build for older distributions
* Fri Oct 19 2007 dmueller@suse.de
- update to 0.14.0:
  * setting if an external diff-display should used is now a simple yes/no box
  * when browsing in working copies or local repositories
  file:// protocol) properties of a single selected item will
  * display-encoding in Annotate / Difference display may changed
  for content not written in KDE defaul locale.
  * feature request: added "Display last change" action (#192)
  * feature request: request #156: check for properties bugtraq:url
  and bugtraq:logregex, replace issue numbers in logoutput with url
  to bugtracker.
- fix build against subversion 1.5
* Mon Aug 27 2007 dmueller@suse.de
- fix build
* Fri Jul 27 2007 dmueller@suse.de
- fix build after cmake update
* Thu Jun 21 2007 stbinner@suse.de
- add %%postun, run kde_post_install, fix invalid .desktop file
* Sun Jun 17 2007 stbinner@suse.de
- update to 0.12.1:
  * when multiple windows opened diff may failed due wrong relative pathes.
  * in KIO module status didn't work - it always returned a fake status.
  * in KIO module in urls of from "proto://user[:pass]@host/"
    the authentication strings were ignored.
* Sat May  5 2007 stbinner@suse.de
- update to 0.12:
  * passwords may stored in more secure kde wallet instead of
    subversions plain file
  * user may select to hide or show unversioned files in
    working copies
  * user may select to hide or show not modified files in
    working copies
  * enhanced internal difference display (Colored, search,
    differences may saved)
  * fix: in urls the wrapper libs overwrites the "@" in
    proto://user@host/path with url-encoding.
  * fix: let user select if them want to checkout/export external
    declarations, too.
* Mon Mar 26 2007 stbinner@suse.de
- update to 0.11.2:
  * missing KIO::special functions implemented (update/add/del)
  * fix: since subversion 1.4 kdesvn made an error when making
    simple diff on commandline ("kdesvn exec diff ")
  * fix: kdevelop always gives a file:/// uri for locals, kio_ksvn
    has to check if this is a working copy uri and transform it to
    uri without protocoll if yes.
  * feature request: Logdialog may display details about items in
    a changeset (difference and annotate) #30
  * feature request: search in blamewindows
  * fix: DirWatcher should not have any display leaks any more and
    should not crash kdesvn on heavy changes.
  * fix: kdesvn could crash when try to open folders where user had
    no execute/read rights for.
  * fix: kdesvn didn't see replaced items as modified items.
  * fix: kdesvn asks now if on commits locks should released.
* Mon Mar  5 2007 stbinner@suse.de
- update to 0.11.1:
  * lock/unlock as commandline action
  * workaround for a subversion-problem with "@" in file/folder names
  * feature: In commit dialog difference of items may displayed
  * feature: in commit dialog all unversioned items may mark for
    adding with one click (bugid 125)
* Mon Nov 27 2006 dmueller@suse.de
- add missing ldconfig call (#223914)
* Thu Nov  2 2006 dmueller@suse.de
- update to 0.11.0:
  * lots of bugfixes
  * more than one mainwindow can be opened
  * colored annotate support
  * integrated external diff support
* Sat Sep 16 2006 stbinner@suse.de
- update to 0.9.3:
  * svnqt now builds against subversion 1.4
* Sun Aug 27 2006 stbinner@suse.de
- update to 0.9.2:
  * fix: utf8 mismatch again
  * fix: sortorder in main view is with all locale case-sensitive
  * featurerequest: on context menu operations from konqueror/
    krusader or other commandline-executes a log-window may stay
    open, context menu for konqueror may switched off.
  * translations de/nl/pa/es/sv updated
* Mon Jul 24 2006 stbinner@suse.de
- update to 0.9.1:
  * fix: subversion were never initialized
  * fix: (buildsystem) missing libs added
  * diffs from within logviewer works across pathchanges
  * fix: checking out urls with special chars like space failed
  * some speedups in diff/cat/get operations
* Tue Jul 18 2006 dmueller@suse.de
- update to 0.9.0:
  * Partial revision tree implemented
  * Revision tree in commandline implemented
  * fix: locale now not only works with utf-8
* Mon Jun 26 2006 stbinner@suse.de
- update to 0.8.5
  * fix: display new items in repository (in difference to local
    working copy) failed sometimes (bug #91)
  * added Punjabi and Catalan translations
* Tue May 30 2006 adrian@suse.de
- fix build for < 10.1
* Mon May 22 2006 stbinner@suse.de
- update to 0.8.4
  * revision tree sometimes failed while detecting renamed items
  * featurerequest: when checking for updates kdesvn displays now
    if a item is locked somewhere
  * featurerequest: mark items with "svn:needs-lock"-property set.
* Tue May  2 2006 stbinner@suse.de
- update to 0.8.3
  * fix: removed a big memory leak
  * fix: when drag&drop starts from kdesvn urls from repositories
    didn't have a revision number
  * fix: kdesvn wasn't able copy items from a specific revision
    (eg, restoring deleted items wasn't possible)
  changes of 0.8.2
  * fix: when creating dir in repository kdesvn/kio-ksvn asked
    twice for a logmessage
  * revision tree has context menues for diffs and detailed
    information
  * fix: log and info on repositories got sometimes wrong revisions
    to search for
  * added spain translation from Mario Palomo
  * executing an item now generates correct url for KDE
  * fix: execute on "enter" key
* Thu Mar 30 2006 stbinner@suse.de
- update to 0.8.1
  * revision tree is generated using dot.
  * colors and direction of tree may set by user
  * fix compile error
  changes of 0.8
  * subversion wrapper made as shared lib so binaries are smaller
  * all possible subversion calls switched to subversion 1.2 API
  * start usage of subversion 1.3 API (only active when build
    against 1.3)
  * display in working copy view when there are newer files in
    repository
  * Fix: activated callbacks for cancel of log/info
  * Fix: script for generating desktop-entries works with bourne
    shell, too.
  * history tree for items may displayed (early stage)
  changes of 0.7.4
  * user may review items before commit will done.
  changes of 0.7.3
  * rapid speed up maintenance of listing of modified and/or
    updated items
  * Option: user may set if storing passwords is default or not.
  * Folders containing conflicted items are marked as conflicted,
    too.
  * Better behavior of tree view when open a folder not yet read
    in.
  * visual markup for conflicted items
* Fri Mar  3 2006 stbinner@suse.de
- fix configure for 10.0, libapr1 is an internal package of it
* Wed Feb 22 2006 stbinner@suse.de
- fix configure for older PLUS
* Wed Feb 15 2006 stbinner@suse.de
- fix GenericName in .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 stbinner@suse.de
- update to 0.7.2
* Tue Jan  3 2006 dmueller@suse.de
- build against apache 2.2.x
* Thu Dec  1 2005 dmueller@suse.de
- update to 0.7.1
* Sat Nov 19 2005 stbinner@suse.de
- add missing dependency for older distribution build
* Fri Nov 11 2005 dmueller@suse.de
- fix build
* Tue Oct 25 2005 stbinner@suse.de
- update to 0.6.3
* Fri Sep 16 2005 dmueller@suse.de
- update to 0.5.3
* Sat Aug 20 2005 dmueller@suse.de
- update 0.5.1
* Fri Aug  5 2005 adrian@suse.de
- initial package of version 0.4.1
